"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pdfViewer = void 0;
const path_1 = __importStar(require("path"));
const fs_1 = require("fs");
const serve_static_1 = __importDefault(require("serve-static"));
const utils_1 = require("./utils");
function pdfViewer(options) {
    const buildDir = path_1.default.resolve((options === null || options === void 0 ? void 0 : options.build) || "./node_modules/pdfjs-viewer-build/viewer/");
    const prefix = path_1.posix.join("/", (options === null || options === void 0 ? void 0 : options.prefix) || "", "/");
    const indexBuildPath = path_1.default.join(buildDir, "index.html");
    const indexPath = path_1.posix.join("/", prefix, "index.html");
    let outDir;
    let promise;
    let copyIndex = true;
    function filterFiles(p) {
        const name = path_1.default.basename(p);
        if (name.endsWith(".js.map"))
            return false;
        if (name.endsWith(".css.map"))
            return false;
        else if (name === "index.html")
            return copyIndex;
        else if (name.endsWith(".pdf"))
            return false;
        else
            return true;
    }
    function testHtmlPath(p) {
        return path_1.posix.join(path_1.posix.dirname(p), "/") === prefix;
    }
    function getTransform(src) {
        const headEndIndex = src.indexOf("</head>");
        const bodyEndIndex = src.indexOf("</body>");
        const head = src.substring(0, headEndIndex);
        const body = src.substring(headEndIndex, bodyEndIndex);
        const tail = src.substring(bodyEndIndex, src.length);
        return (html => {
            var _a, _b;
            const headTags = ((_a = html.match(/<head>(.*?)<\/head>/s)) === null || _a === void 0 ? void 0 : _a[1]) || "";
            const bodyTags = ((_b = html.match(/<body>(.*?)<\/body>/s)) === null || _b === void 0 ? void 0 : _b[1]) || "";
            return `${head}${headTags}${body}${bodyTags}${tail}`;
        });
    }
    return {
        name: "vite-plugin-pdfjs-viewer",
        configResolved(config) {
            outDir = path_1.default.join(config.build.outDir, prefix);
        },
        buildStart() {
            promise = fs_1.promises.readFile(indexBuildPath, { encoding: "utf8" })
                .then(src => getTransform(src));
        },
        transformIndexHtml(html, ctx) {
            return __awaiter(this, void 0, void 0, function* () {
                if (testHtmlPath(ctx.path)) {
                    if (ctx.path === indexPath)
                        copyIndex = false;
                    return (yield promise)(html);
                }
                else {
                    return html;
                }
            });
        },
        configureServer(server) {
            const route = path_1.posix.join(server.config.base, prefix);
            const serve = (0, serve_static_1.default)(buildDir, Object.assign(Object.assign({}, options === null || options === void 0 ? void 0 : options.serve), { index: false }));
            server.middlewares.use(route, serve);
        },
        closeBundle() {
            return __awaiter(this, void 0, void 0, function* () {
                yield (0, utils_1.copyFilesRecursive)(buildDir, outDir, filterFiles);
            });
        }
    };
}
exports.pdfViewer = pdfViewer;
exports.default = pdfViewer;
